@@ -1155,6 +1155,7 @@ def process(jsonstr,filepath,jpath : str = None):
     year
     date
     """
+    df=df.fillna(method="ffill")
     df=df.drop(columns=["currency_symbol","year","date"])
     df = df.astype(float)
 
@@ -1398,7 +1399,14 @@ class CoreResolver(Resolver):
             
             invalid_cols=fcol[fcol["valid"] == "N"]["column"].tolist()
             logging.debug(f"DROPPING invalid cols {invalid_cols}")
-            ddx=ddx.drop(columns=invalid_cols,axis=1)
+
+            dropcols=[]
+
+            for col in invalid_cols:
+                if col in ddx.columns:
+                    dropcols.append(col)
+
+            ddx=ddx.drop(columns=dropcols,axis=1)
             ddx.to_parquet(filepath)
         except Exception as ex:
             print(f"Error {ex} in CORE {ticker}")
